@@ -10,11 +10,11 @@ FTN::Database - FTN SQL Database related operations for Fidonet/FTN related proc
 
 =head1 VERSION
 
-Version 0.20
+Version 0.25
 
 =cut
 
-our $VERSION = '0.20';
+our $VERSION = '0.25';
 
 =head1 DESCRIPTION
 
@@ -24,14 +24,14 @@ SQL database engine is one for which a DBD module exists, defaulting to SQLite.
 
 =head1 EXPORT
 
-The following functions are available in this module:  create_ftndb, open_ftndb,
-close_ftndb, and drop_ftndb.
+The following functions are available in this module:  create_ftn_database, open_ftn_database,
+close_ftn_database, drop_ftn_database, drop_ftn_table, create_ftn_index, and drop_ftn_index.
 
 =head1 FUNCTIONS
 
-=head2 create_ftndb
+=head2 create_ftn_database
 
-Syntax:  create_ftndb($db_handle, $database_name);
+Syntax:  create_ftn_database($db_handle, $database_name);
 
 Create an SQL database for use for Fidonet/FTN processing, where
 $db_handle is an existing open database handle and $database_name
@@ -39,7 +39,7 @@ is the name of the database being created.
 
 =cut
 
-sub create_ftndb {
+sub create_ftn_database {
 
     my($db_handle, $database_name) = @_;
 
@@ -48,12 +48,12 @@ sub create_ftndb {
     $db_handle->do("$sql_statement") or croak($DBI::errstr);
 
     return(0);
-    
+
 }
 
-=head2 open_ftndb
+=head2 open_ftn_database
 
-Syntax:  $db_handle = open_ftndb(\%db_options);
+Syntax:  $db_handle = open_ftn_database(\%db_options);
 
 Open a database for Fidonet/FTN processing, where $db_handle is the
 database handle being returned to the calling program and the referenced
@@ -61,22 +61,22 @@ hash contains the following items:
 
 =over
 
-=item	Type
+=item   Type
 
 The database type.  This needs to be a database type for which 
 a DBD module exists, the type being the name as used in the DBD
 module.  The default type to be used is SQLite.
 
-=item	Name
+=item   Name
 
 The name of the database to be opened.  If the Type is SQLite, this
 is a filename and path to the database file.
 
-=item	User
+=item   User
 
 The database user, which should already have the neccesary priviledges.
 
-=item	Password
+=item   Password
 
 The database password for the database user.
 
@@ -84,7 +84,7 @@ The database password for the database user.
 
 =cut
 
-sub open_ftndb {
+sub open_ftn_database {
 
     use DBI;
 
@@ -92,36 +92,36 @@ sub open_ftndb {
     my $option = shift;
 
     ( my $db_handle = DBI->connect(
-    		"dbi:${$option}{'Type'}:dbname=${$option}{'Name'}",
-    		${$option}{'User'},
-    		${$option}{'Password'} ) )
-	or croak($DBI::errstr);
+        "dbi:${$option}{'Type'}:dbname=${$option}{'Name'}",
+        ${$option}{'User'},
+        ${$option}{'Password'} ) )
+    or croak($DBI::errstr);
 
     return($db_handle);
-    
+
 }
 
-=head2 close_ftndb
+=head2 close_ftn_database
 
-Syntax:  close_ftndb($db_handle);
+Syntax:  close_ftn_database($db_handle);
 
 Closing an FTN database, where $db_handle is an existing open database handle.
 
 =cut
 
-sub close_ftndb {
+sub close_ftn_database {
 
     my $db_handle = shift;
 
     ( $db_handle->disconnect ) or croak($DBI::errstr);
 
     return(0);
-    
+
 }
 
-=head2 drop_ftndb
+=head2 drop_ftn_database
 
-Syntax:  drop_ftndb($db_handle, $database_name);
+Syntax:  drop_ftn_database($db_handle, $database_name);
 
 Drop an SQL database being used for Fidonet/FTN processing if
 it exists, where $db_handle is an existing open database handle
@@ -129,7 +129,7 @@ and $database_name is the name of the database being dropped.
 
 =cut
 
-sub drop_ftndb {
+sub drop_ftn_database {
 
     my($db_handle, $database_name) = @_;
 
@@ -138,7 +138,76 @@ sub drop_ftndb {
     $db_handle->do("$sql_statement") or croak($DBI::errstr);
 
     return(0);
-    
+
+}
+
+=head2 drop_ftn_table
+
+Syntax:  drop_ftn_table($db_handle, $table_name);
+
+Drop an FTN table from an SQL database being used for Fidonet/FTN
+processing if it exists, where $db_handle is an existing open database handle
+and $table_name is the name of the table to be dropped.
+
+=cut
+
+sub drop_ftn_table {
+
+    my($db_handle, $table_name) = @_;
+
+    my $sql_statement = "DROP TABLE IF EXISTS $table_name";
+
+    $db_handle->do("$sql_statement") or croak($DBI::errstr);
+
+    return(0);
+
+}
+
+=head2 create_ftn_index
+
+Syntax:  create_ftn_index($db_handle, $table_name, $index_name, $indexed_fields);
+
+Create an index named $index_name on table $table_name in an SQL database being
+used for Fidonet/FTN processing;  where $db_handle is an existing open database
+handle, the $table_name is the name of the table that is being indexed, and
+$index_name is the name of the index itself.  The index is created on the
+fields listed in $indexed_fields, with the field names separated by commas.
+
+=cut
+
+sub create_ftn_index {
+
+    my($db_handle, $table_name, $index_name, $indexed_fields) = @_;
+
+    my $sql_statement = "CREATE INDEX $index_name ";
+    $sql_statement .= "ON $table_name ($indexed_fields) ";
+
+    $db_handle->do("$sql_statement") or croak($DBI::errstr);
+
+    return(0);
+
+}
+
+=head2 drop_ftn_index
+
+Syntax:  drop_ftn_index($db_handle,$index_name);
+
+Drop an index from an FTN table in an SQL database being used for Fidonet/FTN
+processing if it exists, where $db_handle is an existing open database handle,
+and $index_name is the name of the index to be dropped.
+
+=cut
+
+sub drop_ftn_index {
+
+    my($db_handle, $index_name) = @_;
+
+    my $sql_statement = "DROP INDEX IF EXISTS $index_name";
+
+    $db_handle->do("$sql_statement") or croak($DBI::errstr);
+
+    return(0);
+
 }
 
 =head1 EXAMPLES
@@ -147,9 +216,9 @@ An example of opening an FTN database, then closing it:
 
     use FTN::Database;
 
-    my $db_handle = open_ftndb(\%db_option);
+    my $db_handle = open_ftn_database(\%db_option);
     ...
-    close_ftndb($db_handle);
+    close_ftn_database($db_handle);
 
 An example of creating a database for FTN related processing, using a
 mysql database:
@@ -158,15 +227,15 @@ mysql database:
 
     my $database_name = "ftndbtst";
     my $db_option = {
-	Type = "mysql",
-	Name = "mysql",
-	User = $db_user,
-	Password = $db_password,
+    Type = "mysql",
+    Name = "mysql",
+    User = $db_user,
+    Password = $db_password,
     };
-    my $db_handle = open_ftndb(\%db_option);
-    create_ftndb($db_handle, $database_name);
+    my $db_handle = open_ftn_database(\%db_option);
+    create_ftn_database($db_handle, $database_name);
     ...
-    close_ftndb($db_handle);
+    close_ftn_database($db_handle);
 
 An example of dropping a database being used for FTN related processing,
 using a mysql database:
@@ -175,15 +244,15 @@ using a mysql database:
 
     my $database_name = "ftndbtst";
     my $db_option = {
-	Type = "mysql",
-	Name = "mysql",
-	User = $db_user,
-	Password = $db_password,
+    Type = "mysql",
+    Name = "mysql",
+    User = $db_user,
+    Password = $db_password,
     };
-    my $db_handle = open_ftndb(\%db_option);
+    my $db_handle = open_ftn_database(\%db_option);
     ...
-    drop_ftndb($db_handle, $database_name);
-    close_ftndb($db_handle);
+    drop_ftn_database($db_handle, $database_name);
+    close_ftn_database($db_handle);
 
 
 =head1 AUTHOR
@@ -192,9 +261,15 @@ Robert James Clay, C<< <jame at rocasa.us> >>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-ftn-database at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=FTN-Database>. I will be
-notified, and then you'll automatically be notified of progress on your bug as I make changes.
+Please report any bugs or feature requests via the web interface at
+L<https://github.com/ftnpl/FTN-Database/issues>. I will be notified,
+and then you'll automatically be notified of progress on your bug
+as I make changes.
+
+Note that you can also report any bugs or feature requests to
+C<bug-ftn-database at rt.cpan.org>, or through the web interface at
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=FTN-Database>;
+however, the FTN-Database Issue tracker is preferred.
 
 =head1 SUPPORT
 
@@ -207,18 +282,14 @@ You can also look for information at:
 
 =over 4
 
+=item * FTN-Database issue tracker
+
+L<https://github.com/ftnpl/FTN-Database/issues>
+
 =item * RT: CPAN's request tracker
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=FTN-Database>
 
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/FTN-Database>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/FTN-Database>
-
 =item * Search CPAN
 
 L<http://search.cpan.org/dist/FTN-Database>
@@ -232,12 +303,12 @@ up to the version at which they were last changed.
 
 =head1 SEE ALSO
 
- L<DBI>, L<FTN::Database::Nodelist>, L<ftndbadm>, L<ftndbadm>,
+ L<DBI>, L<FTN::Database::Nodelist>, L<ftnpldb-admin>,
  and L<ftnpldb-nodelist>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2010 Robert James Clay, all rights reserved.
+Copyright 2010-2011 Robert James Clay, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
